#
# spec file for package python-keyczar
#
# Copyright (c) 2009-2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define pkgname keyczar

Name:           python-keyczar
Version:        0.715
Release:        4.1
License:        Apache-2.0
Summary:        Toolkit for safe and simple cryptography
Url:            http://www.keyczar.org
Group:          Development/Languages/Python
Source0:        %{name}-%{version}.tar.gz
Source1:        keyczart.1
BuildRequires:  python-asn1 >= 0.0.8a
BuildRequires:  python-devel
BuildRequires:  python-pycrypto
BuildRequires:  python-setuptools
Requires:       python-asn1 >= 0.0.8a
Requires:       python-pycrypto
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
%py_requires
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
%endif
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%description
Keyczar is an open source cryptographic toolkit designed to make it easier
and safer for developers to use cryptography in their applications.
Keyczar supports authentication and encryption with both symmetric and
asymmetric keys.

Some features of Keyczar include:

 - A simple API
 - Key rotation and versioning
 - Safe default algorithms, modes, and key lengths
 - Automated generation of initialization vectors and ciphertext signatures
 - Keyczar was originally developed by members of the Google Security Team

%prep
%setup -q
find . -name \*.py -exec sed -i 's|#!/usr/bin/python2.4|#!%{_bindir}/python|g' {} \;

%build
python setup.py build

%check
export PYTHONPATH=$(pwd)/build/lib
cd tests/keyczar_tests
python alltests.py

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# install keyczart.py as an executable binary 
echo "#!%{_bindir}/python" >> %{buildroot}%{python_sitelib}/keyczar/keyczart.py.new
cat %{buildroot}%{python_sitelib}/keyczar/keyczart.py >> %{buildroot}%{python_sitelib}/keyczar/keyczart.py.new
mv %{buildroot}%{python_sitelib}/keyczar/keyczart.py.new %{buildroot}%{python_sitelib}/keyczar/keyczart.py
chmod +x %{buildroot}%{python_sitelib}/keyczar/keyczart.py
mkdir -p %{buildroot}%{_bindir}
# include man page
install -Dm644 %{SOURCE1} %{buildroot}%{_mandir}/man1/keyczart.1

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc LICENSE README PKG-INFO doc/
%{_mandir}/man1/keyczart.1*
%{python_sitelib}/keyczar
%{python_sitelib}/python_keyczar-*.egg-info
%{_bindir}/keyczart

%changelog
* Mon Sep 28 2015 michael@stroeder.com
- added build dependency on python-setuptools
- symbolic link /usr/bin/keyczart not needed anymore
- update to version 0.715
  * Change version numbering to match PEP-0440
  * Unpadding happens after MAC validation to prevent padding oracle attacks
  * Added Encoding options to all crypto operations to select whether or not
    not encoding should be used.
  * Python version setup improved for PyPi.
  * AttachedSign with empty nonce now correctly functions.
* Thu Apr 18 2013 lars@linux-schulserver.de
- add LICENSE file to doc
* Wed Apr 17 2013 lars@linux-schulserver.de
- update to version 0.71c:
  + Remove hashbangs from code
  + Make test files executable
  + Add LICENSE file to repo and MANIFEST.in to comply with ASL 2.0
  + Bumped version to 0.71c in setup.py etc.
- added man page
- specfile cleanup
* Sat Sep 22 2012 hpj@urpla.net
- update to version 0.71b
* Wed Oct 13 2010 hpj@urpla.net
- fix too small rsa key size for test case
* Thu Aug 20 2009 hpj@urpla.net
- add patch to show max oaep size
* Thu Aug 20 2009 hpj@urpla.net
- Initial creation of package python-keyczar-0.6b
